<?php

namespace Intergo\Log\LaravelHelpers\Services;

use Illuminate\Support\Str;
use Intergo\Log\Contracts\LoggingFieldsEnum;
use Monolog\LogRecord;

/**
 * Fix messages to graylog of GelfProcessor
 *
 * @author Panayiotis Halouvas <phalouvas@kainotomo.com>
 */
class GelfProcessor
{
    /**
     * Transform a "ID" string record into a "id_smsto" value.
     * Transform a "MESSAGE" string record into a "message_smsto" value.
     *
     * @param array $record
     * @return array
     * @author Panayiotis Halouvas <phalouvas@kainotomo.com>
     *
     */
    public function __invoke(LogRecord $record): LogRecord
    {
        $context = $record->context;

        $traceid_exist = in_array('trace_id', array_keys($context));
        if (!$traceid_exist) {
            $context['trace_id'] = $this->generateTraceId();
        }

        foreach ($context as $key => $value) {
            if (strtoupper($key) === 'ID') {
                $context['id_' . strtolower(getenv('APP_NAME'))] = $value;
                unset($context[$key]);
            }
            if (strtoupper($key) === 'MESSAGE') {
                $context['message_' . strtolower(getenv('APP_NAME'))] = $value;
                unset($context[$key]);
            }
        }

        $user = \Illuminate\Support\Facades\Auth::user();
        if ($user) {
            $context['email'] = $context['email'] ?? $user->email;
            $context[LoggingFieldsEnum::AUTH_USER_ID] = $context[LoggingFieldsEnum::AUTH_USER_ID] ?? $user->id;
        }

        return $record->with(context: $context);
    }

    /**
     * Generate a random Trace id to use it to track the flow of a request
     *
     * @return mixed
     */
    private function generateTraceId()
    {
        return Str::random(32);
    }
}
